@@ -242,7 +242,7 @@ class ProjectMergeRequest(
         manager = ProjectCommitManager(self.manager.gitlab, parent=self.manager._parent)
         return RESTObjectList(manager, ProjectCommit, data_list)
 
-    @cli.register_custom_action("ProjectMergeRequest")
+    @cli.register_custom_action("ProjectMergeRequest", optional=("access_raw_diffs",))
     @exc.on_http_error(exc.GitlabListError)
     def changes(self, **kwargs: Any) -> Union[Dict[str, Any], requests.Response]:
         """List the merge request changes.
@@ -327,6 +327,24 @@ class ProjectMergeRequest(
         data: Dict[str, Any] = {}
         return self.manager.gitlab.http_put(path, post_data=data, **kwargs)
 
+    @cli.register_custom_action("ProjectMergeRequest")
+    @exc.on_http_error(exc.GitlabMRResetApprovalError)
+    def reset_approvals(
+        self, **kwargs: Any
+    ) -> Union[Dict[str, Any], requests.Response]:
+        """Clear all approvals of the merge request.
+
+        Args:
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabMRResetApprovalError: If reset approval failed
+        """
+        path = f"{self.manager.path}/{self.encoded_id}/reset_approvals"
+        data: Dict[str, Any] = {}
+        return self.manager.gitlab.http_put(path, post_data=data, **kwargs)
+
     @cli.register_custom_action("ProjectMergeRequest")
     @exc.on_http_error(exc.GitlabGetError)
     def merge_ref(self, **kwargs: Any) -> Union[Dict[str, Any], requests.Response]:
@@ -401,15 +419,18 @@ class ProjectMergeRequestManager(CRUDMixin, RESTManager):
     _create_attrs = RequiredOptional(
         required=("source_branch", "target_branch", "title"),
         optional=(
+            "allow_collaboration",
+            "allow_maintainer_to_push",
+            "approvals_before_merge",
             "assignee_id",
+            "assignee_ids",
             "description",
-            "target_project_id",
             "labels",
             "milestone_id",
             "remove_source_branch",
-            "allow_maintainer_to_push",
-            "squash",
             "reviewer_ids",
+            "squash",
+            "target_project_id",
         ),
     )
     _update_attrs = RequiredOptional(
