@@ -82,6 +82,25 @@ def test_sidekiq_compound_metrics(gl):
     assert "queues" in out
 
 
+@pytest.mark.gitlab_premium
+def test_geo_nodes(gl):
+    # Very basic geo nodes tests because we only have 1 node.
+    nodes = gl.geonodes.list()
+    assert isinstance(nodes, list)
+
+    status = gl.geonodes.status()
+    assert isinstance(status, list)
+
+
+@pytest.mark.gitlab_premium
+def test_gitlab_license(gl):
+    license = gl.get_license()
+    assert "user_limit" in license
+
+    with pytest.raises(gitlab.GitlabLicenseError, match="The license key is invalid."):
+        gl.set_license("dummy key")
+
+
 def test_gitlab_settings(gl):
     settings = gl.settings.get()
     settings.default_projects_limit = 42
