@@ -5,6 +5,7 @@ import tempfile
 import time
 import uuid
 from subprocess import check_output
+from typing import Optional
 
 import pytest
 import requests
@@ -12,6 +13,7 @@ import requests
 import gitlab
 import gitlab.base
 from tests.functional import helpers
+from tests.functional.fixtures.docker import *  # noqa
 
 SLEEP_TIME = 10
 
@@ -35,7 +37,7 @@ def gitlab_version(gl) -> GitlabVersion:
 
 
 @pytest.fixture(scope="session")
-def fixture_dir(test_dir) -> pathlib.Path:
+def fixture_dir(test_dir: pathlib.Path) -> pathlib.Path:
     return test_dir / "functional" / "fixtures"
 
 
@@ -54,7 +56,8 @@ def gitlab_container_name() -> str:
 
 @pytest.fixture(scope="session")
 def gitlab_docker_port(docker_services, gitlab_service_name: str) -> int:
-    return docker_services.port_for(service=gitlab_service_name, container_port=80)
+    port: int = docker_services.port_for(gitlab_service_name, container_port=80)
+    return port
 
 
 @pytest.fixture(scope="session")
@@ -65,7 +68,7 @@ def gitlab_url(docker_ip: str, gitlab_docker_port: int) -> str:
 def reset_gitlab(gl: gitlab.Gitlab) -> None:
     """Delete resources (such as projects, groups, users) that shouldn't
     exist."""
-    if is_gitlab_ee(gl):
+    if helpers.get_gitlab_plan(gl):
         logging.info("GitLab EE detected")
         # NOTE(jlvillal): By default in GitLab EE it will wait 7 days before
         # deleting a group. Disable delayed group/project deletion.
@@ -112,7 +115,7 @@ def reset_gitlab(gl: gitlab.Gitlab) -> None:
             helpers.safe_delete(user, hard_delete=True)
 
 
-def set_token(container, fixture_dir):
+def set_token(container: str, fixture_dir: pathlib.Path) -> str:
     logging.info("Creating API token.")
     set_token_rb = fixture_dir / "set_token.rb"
 
@@ -155,26 +158,6 @@ def temp_dir() -> pathlib.Path:
     return pathlib.Path(tempfile.gettempdir())
 
 
-@pytest.fixture(scope="session")
-def docker_compose_file(fixture_dir):
-    return fixture_dir / "docker-compose.yml"
-
-
-@pytest.fixture(scope="session")
-def docker_compose_project_name():
-    """Set a consistent project name to enable optional reuse of containers."""
-    return "pytest-python-gitlab"
-
-
-@pytest.fixture(scope="session")
-def docker_cleanup(request):
-    """Conditionally keep containers around by overriding the cleanup command."""
-    if request.config.getoption("--keep-containers"):
-        # Print version and exit.
-        return "-v"
-    return "down -v"
-
-
 @pytest.fixture(scope="session")
 def check_is_alive():
     """
@@ -224,7 +207,7 @@ def wait_for_sidekiq(gl):
     Use this with asserts for slow tasks (group/project/user creation/deletion).
     """
 
-    def _wait(timeout=30, step=0.5):
+    def _wait(timeout: int = 30, step: float = 0.5, allow_fail: bool = False) -> bool:
         for count in range(timeout):
             time.sleep(step)
             busy = False
@@ -235,6 +218,7 @@ def wait_for_sidekiq(gl):
             if not busy:
                 return True
             logging.info(f"sidekiq busy {count} of {timeout}")
+        assert allow_fail, "sidekiq process should have terminated but did not."
         return False
 
     return _wait
@@ -298,21 +282,27 @@ def gl(gitlab_config):
     return instance
 
 
-def is_gitlab_ee(gl: gitlab.Gitlab) -> bool:
-    """Determine if we are running with GitLab EE as opposed to GitLab CE"""
-    try:
-        license = gl.get_license()
-    except gitlab.exceptions.GitlabLicenseError:
-        license = None
-    # If we have a license then we assume we are running on GitLab EE
-    if license:
-        return True
-    return False
-
-
 @pytest.fixture(scope="session")
-def gitlab_ee(gl) -> bool:
-    return is_gitlab_ee(gl=gl)
+def gitlab_plan(gl: gitlab.Gitlab) -> Optional[str]:
+    return helpers.get_gitlab_plan(gl)
+
+
+@pytest.fixture(autouse=True)
+def gitlab_premium(gitlab_plan, request) -> None:
+    if gitlab_plan in ("premium", "ultimate"):
+        return
+
+    if request.node.get_closest_marker("gitlab_ultimate"):
+        pytest.skip("Test requires GitLab Premium plan")
+
+
+@pytest.fixture(autouse=True)
+def gitlab_ultimate(gitlab_plan, request) -> None:
+    if gitlab_plan == "ultimate":
+        return
+
+    if request.node.get_closest_marker("gitlab_ultimate"):
+        pytest.skip("Test requires GitLab Ultimate plan")
 
 
 @pytest.fixture(scope="session")
@@ -547,6 +537,13 @@ def group_label(group):
     return group.labels.create(data)
 
 
+@pytest.fixture(scope="module")
+def epic(group):
+    """Fixture for group epic API resource tests."""
+    _id = uuid.uuid4().hex
+    return group.epics.create({"title": f"epic-{_id}", "description": f"Epic {_id}"})
+
+
 @pytest.fixture(scope="module")
 def variable(project):
     """Variable fixture for project variable API resource tests."""
